==> additional-functions-0.7.3.tgz: package/progressions.js <==
class ArithmeticProgression{
    
    d = 0;
    a = [];
    
    constructor(start, d){
        this.a.push(start);
        this.d = d;
    }

    getNth(n){
        return this.a[0] + (n - 1) * this.d;
    }

    countToNth(n){
        for(let _ = this.a.length; _ < n; _ ++){
            this.a.push(this.a[this.a.length - 1] + this.d);
        }
    }

    getToNth(n){
        this.countToNth(n);
        return this.a;
    }

    getSumToNth(n){
        return ~~(n * (this.a[0] + this.getNth(n)) / 2);
    }
}

class GeometricProgression{
    
    q = 1;
    b = [];
    
    constructor(start, q){
        if(start == 0 || q == 0){
            console.log("b0 or q can't be 0");
            return; 
        }
        this.b.push(start);
        this.q = q;
    }

    getNth(n){
        return this.b[0] * (this.q ** (n - 1));
    }

    countToNth(n){
        for(let _ = this.b.length; _ < n; _ ++){
            this.b.push(this.b[this.b.length - 1] * this.q);
        }
    }

    getToNth(n){
        this.countToNth(n);
        return this.b;
    }

    getSumToNth(n){
        if(this.q == 1) return n * this.b[0];
        return ~~((this.b[0] * ((this.q ** n) - 1)) / (this.q - 1));
    }

    getProdToNth(n){
        return ~~((this.b[0] * this.get_nth(n)) ** (n / 2));
    }
}

class HarmonicProgression{
    
    d = 0;
    c = [];
    
    constructor(start, d){
        this.c.push(start);
        this.d = d;
    }

    getNth(n){
        return ((this.c[0] ** -1) + (n - 1) * this.d) ** -1;
    }

    countToNth(n){
        for(let _ = this.c.length; _ < n; _ ++){
            this.c.push(((this.c[this.c.length - 1] ** -1) + this.d) ** -1);
        }
    }

    getToNth(n){
        this.countToNth(n);
        return this.c;
    }
}

module.exports = {ArithmeticProgression, GeometricProgression, HarmonicProgression};

==> additional-functions-0.7.4.tgz: package/progressions.js <==
class ArithmeticProgression{
    
    d = 0;
    a = [];
    
    constructor(start, d){
        this.a.push(start);
        this.d = d;
    }

    getNth(n){
        return this.a[0] + (n - 1) * this.d;
    }

    countToNth(n){
        for(let _ = this.a.length; _ < n; _ ++){
            this.a.push(this.a[this.a.length - 1] + this.d);
        }
    }

    getToNth(n){
        this.countToNth(n);
        return this.a;
    }

    getSumToNth(n){
        return ~~(n * (this.a[0] + this.getNth(n)) / 2);
    }
}

class GeometricProgression{
    
    q = 1;
    b = [];
    
    constructor(start, q){
        if(start == 0 || q == 0){
            console.log("b0 or q can't be 0");
            return; 
        }
        this.b.push(start);
        this.q = q;
    }

    getNth(n){
        return this.b[0] * (this.q ** (n - 1));
    }

    countToNth(n){
        for(let _ = this.b.length; _ < n; _ ++){
            this.b.push(this.b[this.b.length - 1] * this.q);
        }
    }

    getToNth(n){
        this.countToNth(n);
        return this.b;
    }

    getSumToNth(n){
        if(this.q == 1) return n * this.b[0];
        return ~~((this.b[0] * ((this.q ** n) - 1)) / (this.q - 1));
    }

    getProdToNth(n){
        return ~~((this.b[0] * this.getNth(n)) ** (n / 2));
    }
}

class HarmonicProgression{
    
    d = 0;
    c = [];
    
    constructor(start, d){
        this.c.push(start);
        this.d = d;
    }

    getNth(n){
        return ((this.c[0] ** -1) + (n - 1) * this.d) ** -1;
    }

    countToNth(n){
        for(let _ = this.c.length; _ < n; _ ++){
            this.c.push(((this.c[this.c.length - 1] ** -1) + this.d) ** -1);
        }
    }

    getToNth(n){
        this.countToNth(n);
        return this.c;
    }
}

module.exports = {ArithmeticProgression, GeometricProgression, HarmonicProgression};
